@@ -1,6 +1,7 @@
-
+import logging
 from pytplot import get_data
 
+
 def cotrans_get_coord(name):
     '''
     This function returns the coordinate system of a tplot variable
@@ -29,5 +30,5 @@ def cotrans_get_coord(name):
         if metadata['data_att'].get('coord_sys'):
             return metadata['data_att']['coord_sys']
 
-    print('Coordinate system not found: ' + name)
-    return None
\ No newline at end of file
+    logging.error('Coordinate system not found: ' + name)
+    return None
